@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-'''Field classes for formatting and validating the serialized object.
-'''
+"""Field classes for formatting and validating the serialized object.
+"""
 # Adapted from https://github.com/twilio/flask-restful/blob/master/flask_restful/fields.py.
 # See the `NOTICE <https://github.com/sloria/marshmallow/blob/master/NOTICE>`_
 # file for more licensing information.
@@ -48,14 +48,22 @@ __all__ = [
 
 
 def validated(f):
-    """Decorator that wraps a field's ``format`` or ``output`` method. If an
-    exception is raised during the execution of the wrapped method or the
-    field object's ``validate`` function evaluates to ``False``, a
-    MarshallingError is raised instead with the underlying exception's
-    error message or the user-defined error message (if defined).
+    """Decorator that wraps a field's ``output`` method.
+
+    If the field is required and the value is missing, we raise a
+    MarshallingError immediately. Otherwise, if an exception is raised
+    during the execution of the wrapped method or the field object's
+    ``validate`` function evaluates to ``False``, a MarshallingError
+    is raised with the underlying exception's error message or the
+    user-defined error message (if defined).
     """
     @wraps(f)
     def decorated(self, *args, **kwargs):
+        if hasattr(self, 'required'):
+            value = self.get_value(args[0], args[1])
+            if self.required and value is None:
+                raise MarshallingError('Missing data for required field.')
+
         try:
             output = f(self, *args, **kwargs)
             if hasattr(self, 'validate') and callable(self.validate):
@@ -80,8 +88,10 @@ class Marshaller(object):
         serialized field names.
     :param bool strict: If ``True``, raise errors if invalid data are passed in
         instead of failing silently and storing the errors.
+    :param callable error_handler: Error handling function that receieves a
+        dictionary of stored errors.
     """
-    def __init__(self, prefix='', strict=False):
+    def __init__(self, prefix='', strict=False, error_handler=None):
         self.prefix = prefix
         self.strict = strict
         self.errors = {}
@@ -111,8 +121,8 @@ class Marshaller(object):
                 item = (key, None)
             except TypeError:
                 # field declared as a class, not an instance
-                if isinstance(field_obj, type) and \
-                    issubclass(field_obj, FieldABC):
+                if (isinstance(field_obj, type) and
+                       issubclass(field_obj, FieldABC)):
                     msg = ('Field for "{0}" must be declared as a '
                                     "Field instance, not a class. "
                                     'Did you mean "fields.{1}()"?'
@@ -182,15 +192,9 @@ class Raw(FieldABC):
         self.required = required
 
     def get_value(self, key, obj):
-        """Return the value for a given key from an object.
-
-        :exception MarshallingError: In case of a required field returning None
-        """
+        """Return the value for a given key from an object."""
         check_key = key if self.attribute is None else self.attribute
-        value = _get_value(check_key, obj)
-        if value is None and self.required:
-            raise MarshallingError("{0!r} is a required field.".format(check_key))
-        return value
+        return _get_value(check_key, obj)
 
     def format(self, value):
         """Formats a field's value. No-op by default, concrete fields should
@@ -214,7 +218,7 @@ class Raw(FieldABC):
 
         :param str key: The attibute or key to get.
         :param str obj: The object to pull the key from.
-        :exception MarshallingError: In case of formatting problem
+        :exception MarshallingError: In case of validation or formatting problem
         """
         value = self.get_value(key, obj)
         if value is None:
@@ -362,6 +366,7 @@ class List(Raw):
                                            "marshmallow.base.FieldABC")
             self.container = cls_or_instance
 
+    @validated
     def output(self, key, data):
         value = self.get_value(key, data)
         # we cannot really test for external dict behavior
@@ -382,7 +387,6 @@ class String(Raw):
     def __init__(self, default='', attribute=None,  *args, **kwargs):
         return super(String, self).__init__(default, attribute, *args, **kwargs)
 
-    @validated
     def format(self, value):
         try:
             return text_type(value)
@@ -414,7 +418,6 @@ class Number(Raw):
         else:
             return self.num_type(value)
 
-    @validated
     def format(self, value):
         try:
             if value is None:
@@ -448,6 +451,7 @@ class FormattedString(Raw):
         super(FormattedString, self).__init__()
         self.src_str = text_type(src_str)
 
+    @validated
     def output(self, key, obj):
         try:
             data = utils.to_marshallable_type(obj)
@@ -475,7 +479,6 @@ class Arbitrary(Number):
     def __init__(self, default=0, attribute=None, **kwargs):
         super(Arbitrary, self).__init__(default=default, attribute=attribute, **kwargs)
 
-    @validated
     def format(self, value):
         try:
             if value is None:
@@ -507,7 +510,6 @@ class DateTime(Raw):
         super(DateTime, self).__init__(default=default, attribute=attribute, **kwargs)
         self.dateformat = format
 
-    @validated
     def format(self, value):
         self.dateformat = self.dateformat or 'rfc'
         format_func = DATEFORMAT_FUNCTIONS.get(self.dateformat, None)
@@ -530,7 +532,6 @@ class LocalDateTime(DateTime):
 class Time(Raw):
     """ISO8601-formatted time string."""
 
-    @validated
     def format(self, value):
         try:
             ret = value.isoformat()
@@ -545,7 +546,6 @@ class Time(Raw):
 class Date(Raw):
     """ISO8601-formatted date string."""
 
-    @validated
     def format(self, value):
         try:
             return value.isoformat()
@@ -560,7 +560,6 @@ class TimeDelta(Raw):
     as a float.
     '''
 
-    @validated
     def format(self, value):
         try:
             return total_seconds(value)
@@ -583,7 +582,6 @@ class Fixed(Number):
                             *args, **kwargs)
         self.precision = MyDecimal('0.' + '0' * (decimals - 1) + '1')
 
-    @validated
     def format(self, value):
         dvalue = utils.float_to_decimal(float(value))
         if not dvalue.is_normal() and dvalue != ZERO:
